##  Overview
This guide explains how to enable automated nightly runs for an inbound Integration API processor by adjusting the processor configuration.
Enabling nightly runs allows you to ensure that your processors work without disruptions after the deprecation of workflows, which occurred on February 15, 2024. Previously, you could configure a custom schedule for a processor using workflows.
